==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/holidays/classes/legacy/user/HpUserDay.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array("_90550bd38ceb94e22c7740269" . "e5a0081" => base64_decode("ZGF5X2l" . "k"), "_ebff9d37a7bb577c57bee4d" . "d9f0e5fd7" => base64_decode("YXJyYX" . "lfdmFs" . "dWVz"), "_7a7732dd8d16ec4e9692cf4467c7" . "a9a3" => base64_decode("U0VMRUNUIGRheV9pZCwgaGFsZl9kYXksIHN0YXR1cywgcHJldl9pZCwgcHJldl9wYXJ0IEZST00gaHBsX3VzZXJfZGF5cyBXSEVSRSB1c2VyX2lkPWludDp1c2VyIEFORCB5ZWFyX251bT1pbnQ6eWVhciBBTkQgb" . "W9udGhfbnVtPWludDptb250aCBBTkQgZGF5X251bT1pbnQ6ZGF5"));






class HpUserDay extends HpDay
{
    var $user;
    var $id;
    var $year;
    var $month;
    var $day_num;
    var $status;
    var $prev_id;
    var $prev_part;
    var $half_day_stat;
    var $user_data;
    function __construct($_8cdb19ba28a936f009914b17ef69c3ee, $user_id, $_67a0d624aebcceb0abd5ce56a53ff06f, $_eb5a034bac26150e74cc0d157e037712 = 0)
    {
        $this->half_day_stat = 0;
        $this->id = $_8cdb19ba28a936f009914b17ef69c3ee;
        $this->user = $user_id;
        if ($_67a0d624aebcceb0abd5ce56a53ff06f instanceof DateDay) {
            
            
            $this->year = $_67a0d624aebcceb0abd5ce56a53ff06f->getYear();
            $this->month = $_67a0d624aebcceb0abd5ce56a53ff06f->getMonth();
            $this->day_num = $_67a0d624aebcceb0abd5ce56a53ff06f->getDay();
        } else {
            $_196663f27c2dc460096fe39e69fd6138 = HpToolKit::Instance();
            
            
            $this->year = $_196663f27c2dc460096fe39e69fd6138->conf->GetRealYear();
            $this->month = $_67a0d624aebcceb0abd5ce56a53ff06f;
            $this->day_num = $_eb5a034bac26150e74cc0d157e037712;
        }
        $this->_load();
    }
    function _load()
    {
        global $db;
        $_7f5aa4e96d4b415a86ed72ebff677cbe = $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_7a7732dd8d16ec4e9692cf4467c7" . "a9a3"];
        $_189840d11056515e52402d1412a0b6e4 = $db->query($_7f5aa4e96d4b415a86ed72ebff677cbe, $this->user, $this->year, $this->month, $this->day_num);
        $_b8cfc2e06d9d1fec1893ea4a054002bf = $_189840d11056515e52402d1412a0b6e4->fetchArray();
        if (isset($_b8cfc2e06d9d1fec1893ea4a054002bf[$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_90550bd38ce" . "b94e22c77402" . "69e5a0081"]])) {
            list($this->id, $this->half_day_stat, $this->status, $this->prev_id, $this->prev_part) = $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_ebff9d37a7bb577c57bee4d" . "d9f0e5fd7"]($_b8cfc2e06d9d1fec1893ea4a054002bf);
        }
        $_196663f27c2dc460096fe39e69fd6138 = HpToolKit::Instance();
        
        
        $_83dcb96e6497727bea94783c6ee8feb5 = $_196663f27c2dc460096fe39e69fd6138->GetDayById($this->id);
        
        
        list($this->id, $this->name, $this->hpl_char, $this->can_decline, $this->can_half_day, $this->limit_action, $this->notify_to, $this->font_color, $this->bg_color, ) = array($_83dcb96e6497727bea94783c6ee8feb5->id, $_83dcb96e6497727bea94783c6ee8feb5->name, $_83dcb96e6497727bea94783c6ee8feb5->hpl_char, $_83dcb96e6497727bea94783c6ee8feb5->can_decline, $_83dcb96e6497727bea94783c6ee8feb5->can_half_day, $_83dcb96e6497727bea94783c6ee8feb5->limit_action, $_83dcb96e6497727bea94783c6ee8feb5->notify_to, $_83dcb96e6497727bea94783c6ee8feb5->font_color, $_83dcb96e6497727bea94783c6ee8feb5->bg_color);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/holidays/classes/legacy/user/HpUserDay.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] = (@$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] ?: array()) + array("_7a7732dd8d16ec4e9692cf44" . "67c7a9a3" => base64_decode("U0VMRUNUIGRheV9pZCwgaGFsZl9kYXksIHN0YXR1cywgcHJldl9pZCwgcHJldl9wYXJ0IEZST00gaHBsX3VzZXJfZGF5cyBXSEVSRSB1c2VyX2lkPWludDp1c2VyIEFORCB5ZWFyX251bT1pbnQ6eWVhciBBTkQgbW9udGhfbnVtPWludDptb250aCBBTkQgZGF5X251bT1pbnQ6" . "ZGF5"), "_90550bd38ceb94e22c774026" . "9e5a0081" => base64_decode("ZGF" . "5X2" . "lk"), "_ebff9d37a7bb577c57bee4dd9f" . "0e5fd7" => base64_decode("YXJyY" . "Xlfdm" . "FsdWV" . "z"));






class HpUserDay extends HpDay
{
    var $user;
    var $id;
    var $year;
    var $month;
    var $day_num;
    var $status;
    var $prev_id;
    var $prev_part;
    var $half_day_stat;
    var $user_data;
    function __construct($_8cdb19ba28a936f009914b17ef69c3ee, $user_id, $_67a0d624aebcceb0abd5ce56a53ff06f, $_eb5a034bac26150e74cc0d157e037712 = 0)
    {
        $this->half_day_stat = 0;
        $this->id = $_8cdb19ba28a936f009914b17ef69c3ee;
        $this->user = $user_id;
        if ($_67a0d624aebcceb0abd5ce56a53ff06f instanceof DateDay) {
            
            
            $this->year = $_67a0d624aebcceb0abd5ce56a53ff06f->getYear();
            $this->month = $_67a0d624aebcceb0abd5ce56a53ff06f->getMonth();
            $this->day_num = $_67a0d624aebcceb0abd5ce56a53ff06f->getDay();
        } else {
            $_196663f27c2dc460096fe39e69fd6138 = HpToolKit::Instance();
            
            
            $this->year = $_196663f27c2dc460096fe39e69fd6138->conf->GetRealYear();
            $this->month = $_67a0d624aebcceb0abd5ce56a53ff06f;
            $this->day_num = $_eb5a034bac26150e74cc0d157e037712;
        }
        $this->_load();
    }
    function _load()
    {
        global $db;
        $_7f5aa4e96d4b415a86ed72ebff677cbe = $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_7a7732dd8d16ec4e9692cf4467c7" . "a9a3"];
        $_189840d11056515e52402d1412a0b6e4 = $db->query($_7f5aa4e96d4b415a86ed72ebff677cbe, $this->user, $this->year, $this->month, $this->day_num);
        $_b8cfc2e06d9d1fec1893ea4a054002bf = $_189840d11056515e52402d1412a0b6e4->fetchArray();
        if (isset($_b8cfc2e06d9d1fec1893ea4a054002bf[$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_90550bd38ceb94e" . "22c7740269e5a008" . "1"]])) {
            list($this->id, $this->half_day_stat, $this->status, $this->prev_id, $this->prev_part) = $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_ebff9d37a7bb577" . "c57bee4dd9f0e5fd" . "7"]($_b8cfc2e06d9d1fec1893ea4a054002bf);
        }
        $_196663f27c2dc460096fe39e69fd6138 = HpToolKit::Instance();
        
        
        $_83dcb96e6497727bea94783c6ee8feb5 = $_196663f27c2dc460096fe39e69fd6138->GetDayById($this->id);
        
        
        list($this->id, $this->name, $this->hpl_char, $this->can_decline, $this->can_half_day, $this->limit_action, $this->notify_to, $this->font_color, $this->bg_color, ) = array($_83dcb96e6497727bea94783c6ee8feb5->id, $_83dcb96e6497727bea94783c6ee8feb5->name, $_83dcb96e6497727bea94783c6ee8feb5->hpl_char, $_83dcb96e6497727bea94783c6ee8feb5->can_decline, $_83dcb96e6497727bea94783c6ee8feb5->can_half_day, $_83dcb96e6497727bea94783c6ee8feb5->limit_action, $_83dcb96e6497727bea94783c6ee8feb5->notify_to, $_83dcb96e6497727bea94783c6ee8feb5->font_color, $_83dcb96e6497727bea94783c6ee8feb5->bg_color);
    }
}
